@@ -130,12 +130,12 @@ static R_CallMethodDef CallEntries[] = {
     {"dtrMatrix_rcond", (DL_FUNC) &dtrMatrix_rcond, 2},
     {"dtrMatrix_solve", (DL_FUNC) &dtrMatrix_solve, 1},
     {"dtrMatrix_validate", (DL_FUNC) &dtrMatrix_validate, 1},
-    {"glmer_bhat", (DL_FUNC) &glmer_bhat, 3},
+    {"glmer_PQL", (DL_FUNC) &glmer_PQL, 1},
     {"glmer_devAGQ", (DL_FUNC) &glmer_devAGQ, 3},
     {"glmer_finalize", (DL_FUNC) &glmer_finalize, 1},
     {"glmer_fixed_update", (DL_FUNC) &glmer_fixed_update, 3},
     {"glmer_init", (DL_FUNC) &glmer_init, 1},
-    {"glmer_PQL", (DL_FUNC) &glmer_PQL, 1},
+    {"glmer_ranef_update", (DL_FUNC) &glmer_ranef_update, 4},
     {"lapack_qr", (DL_FUNC) &lapack_qr, 2},
     {"lCholCMatrix_solve", (DL_FUNC) &lCholCMatrix_solve, 1},
     {"lCholCMatrix_lgCMatrix_solve", (DL_FUNC) &lCholCMatrix_lgCMatrix_solve, 2},
